@@ -129,26 +129,29 @@ def loadPreset(preset_name):
 
 def getAvailableProfiles():
         """Checks if tweakr is installed and returns the profiles"""
-        state = subprocess.Popen(['dpkg-query', '-l', 'tweakr'], 
-                             stdout=subprocess.PIPE).communicate(
-                             )[0].split("\n")[5].split()[0]
-        if state == "ii":
-            try:
-                profiles = []
-                tweaker_profiles = subprocess.Popen(
-                        ['gconftool-2', '--all-dirs', '/system/tweakr'],
-                        stdout=subprocess.PIPE).communicate(
-                        )[0].split("\n")
-                for profile in tweaker_profiles:
-                    try:
-                        profiles.append(profile.split("/")[3])
-                    except IndexError:
-                        pass
-                if len(profiles) == 0:
+        try:
+            state = subprocess.Popen(['dpkg-query', '-l', 'tweakr'], 
+                                 stdout=subprocess.PIPE).communicate(
+                                 )[0].split("\n")[5].split()[0]
+            if state == "ii":
+                try:
+                    profiles = []
+                    tweaker_profiles = subprocess.Popen(
+                            ['gconftool-2', '--all-dirs', '/system/tweakr'],
+                            stdout=subprocess.PIPE).communicate(
+                            )[0].split("\n")
+                    for profile in tweaker_profiles:
+                        try:
+                            profiles.append(profile.split("/")[3])
+                        except IndexError:
+                            pass
+                    if len(profiles) == 0:
+                        profiles = ["General"]
+                except IndexError:
                     profiles = ["General"]
-            except IndexError:
+            else:
                 profiles = ["General"]
-        else:
+        except IndexError:
             profiles = ["General"]
         profiles.append("Silent")
         return profiles
